# -*- coding: utf-8 -*-
# @Time    : 2022/8/5 2:09 PM
# @Author  : zhaolun@deepwise.com
# @Site    : http://192.168.10.111:3000/MIG/DW_Research_Platform
# @File    : example.py
# @Software: PyCharm


def add_one(number):
    return number + 1